@@ -97,6 +97,7 @@ def add_link_arguments(cap):
         default="unsupplied_implies_use_CXX")
     cap.add(
         "--LDFLAGS",
+        "--LINKFLAGS",
         help="Linker flags",
         default="unsupplied_implies_use_CXXFLAGS")
 
@@ -341,14 +342,12 @@ def _strip_quotes(args):
             # Can't just use the for loop directly because that would
             # try and process every character in a string
             if ct.utils.is_nonstr_iter(value):
-                for element in value:
-                    element = element.strip("'")
-                    element = element.strip('"')
+                for index, element in enumerate(value):
+                    value[index] = element.strip('"\'')
             else:
                 try:
                     # Otherwise assume its a string
-                    setattr(args, name, value.strip("'"))
-                    setattr(args, name, getattr(args,name).strip('"'))
+                    setattr(args, name, value.strip('"\''))
                 except:
                     pass
 
@@ -404,7 +403,9 @@ def substitutions(args, verbose=None):
     if verbose >= 2:
         verboseprintconfig(args)
 
-def parseargs(cap, argv=None, verbose=None):
+
+def parseargs(cap, argv, verbose=None):
+    ''' argv must be the logical equivalent of sys.argv[1:] '''
     args = cap.parse_args(args=argv)
     _strip_quotes(args)
 
