@@ -5,6 +5,8 @@ from __future__ import unicode_literals
 import os
 import sys
 from io import open
+PY3 = sys.version_info[0] == 3
+
 
 import configargparse
 
@@ -98,14 +100,14 @@ class LinkRuleCreator(object):
         allprerequisites += " "
         allprerequisites += " ".join(object_names)
 
-        all_magic_ldflags = set()
+        all_magic_ldflags = ct.utils.OrderedSet()
         if not suppressmagicldflags:
             for source in completesources:
                 magic_flags = self.hunter.magicflags(source)
-                all_magic_ldflags |= magic_flags.get('LDFLAGS', set())
+                all_magic_ldflags |= magic_flags.get('LDFLAGS', ct.utils.OrderedSet())
                 all_magic_ldflags |= magic_flags.get(
                     'LINKFLAGS',
-                    set())  # For backward compatibility with cake
+                    ct.utils.OrderedSet())  # For backward compatibility with cake
         recipe = ""
         if self.args.verbose >= 1:
             recipe += " ".join(["@echo ...", outputname, ";"])
@@ -160,7 +162,7 @@ class ExeLinkRuleCreator(LinkRuleCreator):
             libname = os.path.join(self.namer.executable_dir(), os.path.basename(dynamiclibrarypathname))
             extraprereqs.append(libname)
 
-        linkrules = set()
+        linkrules = ct.utils.OrderedSet()
         for source in sources:
             if self.args.verbose >= 4:
                 print(
@@ -233,11 +235,12 @@ class MakefileCreator:
         except OSError:
             # If the Makefile doesn't exist then we aren't up to date
             if self.args.verbose > 7:
+                print('Regenerating Makefile.')
                 print("Could not determine mtime for {}. Assuming that it doesn't exist.".format(self.args.makefilename))
             return False
 
         # See how the Makefile was previously generated
-        expected = ' '.join(["# Makefile generated by"]+sys.argv)
+        expected = ''.join(["# Makefile generated by ", str(self.args)])
         with open(self.args.makefilename, mode='r', encoding='utf-8') as mfile:
             previous = mfile.readline().strip()
             if previous != expected:
@@ -253,7 +256,9 @@ class MakefileCreator:
             for ff in filelist:
                 if ct.wrappedos.getmtime(ff) > makefilemtime:
                     if self.args.verbose > 7:
-                        print("mtime for {} is newer than mtime for the Makefile".format(ct.wrappedos.getmtime(ff))) 
+                        print('Regenerating Makefile.')
+                        print("mtime {} for {} is newer than mtime for the Makefile"
+                                .format(ct.wrappedos.getmtime(ff),ff)) 
                     return False
         
         if self.args.verbose > 9:
@@ -503,7 +508,7 @@ class MakefileCreator:
                 filename)
 
         deplist = self.hunter.header_dependencies(filename)
-        prerequisites = sorted([str(dep) for dep in deplist])        
+        prerequisites = [filename] + sorted([str(dep) for dep in deplist])        
 
         self.object_directories.add(self.namer.object_dir(filename))
         obj_name = self.namer.object_pathname(filename)
@@ -594,7 +599,10 @@ class MakefileCreator:
         """ Take a list of rules and write the rules to a Makefile """
         with open(makefile_name, mode='w', encoding='utf-8') as mfile:
             mfile.write("# Makefile generated by ")
-            mfile.write(' '.join(sys.argv))
+            if PY3:
+                mfile.write(str(self.args))
+            else:
+                mfile.write(str(self.args).decode('unicode_escape'))
             mfile.write("\n")
             for rule in self.rules:
                 rule.write(mfile)
@@ -602,8 +610,11 @@ class MakefileCreator:
     def clear_cache(self):
         """ Only useful in test scenarios where you need to reset to a pristine state """
         ct.wrappedos.clear_cache()
+        ct.utils.clear_cache()
+        ct.git_utils.clear_cache()
         self.namer.clear_cache()
         self.hunter.clear_cache()
+        ct.magicflags.MagicFlagsBase.clear_cache()
 
 def main(argv=None):
     cap = configargparse.getArgumentParser()
