@@ -28,7 +28,10 @@ def cakedir():
 def samplesdir():
     return os.path.realpath(os.path.join(ctdir(), "../samples"))
 
-def create_temp_config(tempdir=None):
+def ctconfdir():
+    return os.path.realpath(os.path.join(ctdir(), "../ct.conf.d"))
+
+def create_temp_config(tempdir=None, filename=None):
     """ User is responsible for removing the config file when 
         they are finished 
     """
@@ -38,12 +41,27 @@ def create_temp_config(tempdir=None):
     except KeyError:
         CC='gcc'
         CXX='g++'
-        
-    tf_handle, tf_name = tempfile.mkstemp(suffix=".conf", text=True, dir=tempdir)
-    with open(tf_name,'w') as ff:
+       
+    if not filename:
+        tf_handle, filename = tempfile.mkstemp(suffix=".conf", text=True, dir=tempdir)
+
+    with open(filename,'w') as ff:
         ff.write('ID=GNU\n')
         ff.write('CC=' + CC + '\n')
         ff.write('CXX=' + CXX + '\n')
         ff.write('CPPFLAGS="-std=c++11"\n')
-    return tf_name
+
+    return filename
+
+def create_temp_ct_conf(tempdir,defaultvariant='debug'):
+    """ User is responsible for removing the config file when 
+        they are finished 
+    """
+    with open(os.path.join(tempdir,'ct.conf'), 'w') as ff:
+        #ff.write('CTCACHE = ' + os.path.join(tempdir,'ct-unittest-cache' + '\n'))
+        #ff.write('CTCACHE = None' + '\n')
+        ff.write(' '.join(['variant =',defaultvariant,'\n']))
+        ff.write("variantaliases = {'dbg':'foo.debug', 'rls':'foo.release'}\n")
+        ff.write('exemarkers = [main]' + '\n')
+        ff.write('testmarkers = unit_test.hpp' + '\n')
 
